<?php

class Shopware_Plugins_Frontend_FintezaAnalytics_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{
    private $ping_install_url = 'https://content.mql5.com/tr?event=Plugin%2BShopware%2BActivate&id=cbgspzdebnimbhhkhankjnebjfajvaceho&ref=https%3A%2F%2Fwww.finteza.com%2F';
    private $ping_uninstall_url = 'https://content.mql5.com/tr?event=Plugin%2BShopware%2BDeactivate&id=cbgspzdebnimbhhkhankjnebjfajvaceho&ref=https%3A%2F%2Fwww.finteza.com%2F';

    public function getVersion()
    {
        $info = json_decode(file_get_contents(__DIR__ . DIRECTORY_SEPARATOR . 'plugin.json'), true);

        try {
            return $info['currentVersion'];
        } catch (Exception $exception) {
            throw new Exception('The plugin has an invalid version file.' . $exception->getMessage());
        }
    }

    public function getLabel()
    {
        $info = json_decode(file_get_contents(__DIR__ . DIRECTORY_SEPARATOR . 'plugin.json'), true);

        try {
            return $info['label'];
        } catch (Exception $exception) {
            throw new Exception('The plugin has an invalid version file.' . $exception->getMessage());
        }
    }

    public function getInfo()
    {
        $info = json_decode(file_get_contents(__DIR__ . DIRECTORY_SEPARATOR . 'plugin.json'), true);

        return [
            'version'     => $this->getVersion(),
            'label'       => $this->getLabel(),
            'name'        => 'FintezaAnalytics',
            'author'      => $info['author'],
            'supplier'    => $info['author'],
            'copyright'   => $info['copyright'],
            'link'        => $info['link'],
            'support'     => $info['support'],
            'description' => file_get_contents(__DIR__ . '/description.txt'),
        ];
    }

    public function install()
    {
        $this->_registerController();
        $this->_createMenu();
        $this->_createEvent();
        $this->_createForm();
        $this->_clearCache();
        $this->ping($this->ping_install_url);

        return [
            'success' => true
        ];
    }

    public function uninstall()
    {
        $this->_removeMenu();
        $this->_clearCache();
        $this->ping($this->ping_uninstall_url);

        return [
            'success' => true
        ];
    }

    private function _registerController()
    {
        $this->registerController('Backend', 'FintezaAnalytics');
        $this->registerController('Frontend', 'FintezaAnalytics');
    }

    private function _createMenu()
    {
        if ($this->assertMinimumVersion('5.2')) {
            $parent = $this->Menu()->findOneBy(['label' => 'Marketing']);
        } else {
            $parent = $this->Menu()->findOneBy('label', 'Marketing');
        }

        $item = $this->createMenuItem([
            'label'      => 'Finteza Analytics',
            'class'      => 'finteza-menu-icon',
            'controller' => 'FintezaAnalytics',
            'action'     => 'index',
            'active'     => 1,
            'position'   => 888,
            'parent'     => $parent,
        ]);
    }

    private function _removeMenu() {
        $menu = $this->Menu()->findOneBy(['label' => 'Finteza Analytics']);

        Shopware()->Models()->remove($menu);
        Shopware()->Models()->flush();
    }

    private function _createEvent()
    {
        try {
            $this->subscribeEvent(
                'Enlight_Controller_Action_PostDispatch_Backend_Index',
                'onBackendIndex'
            );

            $this->subscribeEvent(
                'Enlight_Controller_Action_PostDispatchSecure_Backend_PluginManager',
                'onBackendPluginManager'
            );

            $this->subscribeEvent(
                'Enlight_Controller_Action_PostDispatch_Frontend',
                'onFrontend'
            );

            $this->subscribeEvent(
                'Shopware_Modules_Basket_AddArticle_Start',
                'onBasketAddArticle'
            );

            $this->subscribeEvent(
                'sBasket::sDeleteArticle::before',
                'onBasketDeleteArticle'
            );

            $this->subscribeEvent(
                'Shopware\Models\Order\Order::postUpdate',
                'onUpdateOrder'
            );
        } catch (Exception $exception) {
            throw new Exception("Error subscribe event. " . $exception->getMessage());
        }
    }

    private function _createForm()
    {
        $form = $this->Form();

        $form->setElement('text', 'FINTEZA_AUTH', [
            'value' => false,
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('text', 'FINTEZA_WEBSITE_ID', [
            'value' => '',
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('boolean', 'FINTEZA_TRACKING_HASH', [
            'value' => false,
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('boolean', 'FINTEZA_TRACKING_LINK', [
            'value' => true,
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('boolean', 'FINTEZA_EXACT_TIME', [
            'value' => false,
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('boolean', 'FINTEZA_TRACKING_HOOKS', [
            'value' => false,
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $form->setElement('text', 'FINTEZA_SIGNATURE', [
            'value' => '',
            'required' => true,
            'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP,
            'hidden' => true,
        ]);

        $parent = $this->Forms()->findOneBy(['name' => 'Interface']);

        $form->setParent($parent);
    }

    private function _clearCache()
    {
        $cacheManager = $this->get('shopware.cache_manager');
        $cacheManager->clearHttpCache();
        $cacheManager->clearConfigCache();
        $cacheManager->clearTemplateCache();
    }

    public function onBackendIndex(\Enlight_Controller_ActionEventArgs $args)
    {
        $controller = $args->getSubject();
        $request = $controller->Request();
        $response = $controller->Response();
        $action = $request->getActionName();
        $view = $controller->View();

        if ($action === 'index') {
            $view->addTemplateDir($this->Path() . 'Views/');
            $view->extendsTemplate('backend/override/index_header.tpl');
        }
    }

    public function onBackendPluginManager(\Enlight_Controller_ActionEventArgs $args)
    {
        $controller = $args->getSubject();
        $request = $controller->Request();
        $response = $controller->Response();
        $action = $request->getActionName();
        $view = $controller->View();

        if ($action === 'load') {
            $view->addTemplateDir($this->Path() . 'Views/');
            $view->extendsTemplate('backend/override/plugin_manager_view_detail_container.js');
        }
    }

    public function onFrontend(\Enlight_Event_EventArgs $args)
    {
        $front = $args->getSubject();
        $request = $front->Request();
        $response = $front->Response();
        $view = $front->View();
        $module = $request->getModuleName();
        $controller = $request->getControllerName();
        $action = $request->getActionName();
        $view->addTemplateDir($this->Path() . 'Views/');

        if (!$this->permitInit()
            || !$request->isDispatched()
            || $response->isException()
            || $request->isXmlHttpRequest()
            || !$view->hasTemplate()
            || $module != 'frontend'
            || $_SERVER['REQUEST_METHOD'] == 'POST'
        ) {
            return;
        }

        // viewProduct
        if ($controller == 'detail' && $action == 'index') {
            $item = (int)$request->getParam('sArticle');

            $article = Shopware()->Modules()->Articles()->sGetArticleById($item);

            if (isset($article['image']['thumbnails'][1]['source'])) {
                $image = $article['image']['thumbnails'][1]['source'];
            } else {
                $image = '';
            }

            $params = [
                'id'       => (int)$article['articleID'],
                'stock'    => $article['isAvailable'],
                'price'    => $article['price_numeric'],
                'name'     => $article['articleName'],
                'category' => $article['categoryID'],
                'url'      => $article['linkDetailsRewrited'],
                'image'    => $image,
            ];

            $this->prepareHook('viewProduct', $params);
        }

        // checkoutOrder
        if ($controller == 'checkout' && $action == 'finish' && Shopware()->Session()->offsetExists('sOrderVariables')) {
           $order = Shopware()->Models()->getRepository('Shopware\Models\Order\Order')->findOneBy(['number' => Shopware()->Session()->sOrderVariables['sOrderNumber']]);

            if (!empty($order)) {
                $this->prepareHook('checkoutOrder', $order);
            }
        }

        $view->assign('finteza_id', $this->Config()->get('FINTEZA_WEBSITE_ID'));
        $view->assign('finteza_hash', $this->Config()->get('FINTEZA_TRACKING_HASH'));
        $view->assign('finteza_link', $this->Config()->get('FINTEZA_TRACKING_LINK'));
        $view->assign('finteza_time', $this->Config()->get('FINTEZA_EXACT_TIME'));
        $view->assign('finteza_tracks', Shopware()->Session()->offsetExists('finteza_tracks') ? Shopware()->Session()->offsetGet('finteza_tracks') : '');

        Shopware()->Session()->offsetSet('finteza_tracks', '');

        $view->extendsTemplate('frontend/override/index.tpl');
    }

    public function onBasketAddArticle(\Enlight_Event_EventArgs $args)
    {
        $ordernumber = $args->get('id');
        $product_id = Shopware()->Modules()->Articles()->sGetArticleIdByOrderNumber($ordernumber);

        $params = [
            'id'       => (int)$product_id,
            'quantity' => $args->get('quantity'),
        ];

        $this->prepareHook('addProductToCart', $params);
    }

    public function onBasketDeleteArticle(\Enlight_Hook_HookArgs $args)
    {
        $basket = Shopware()->Modules()->Basket()->sGetBasket();

        foreach ($basket['content'] as $basket_product) {
            if ($basket_product['id'] == $args->get('id')) {
                $params = [
                    'id' => (int)$basket_product['articleID'],
                ];

                $this->prepareHook('removeProductFromCart', $params);
            }
        }
    }

    public function onUpdateOrder(\Enlight_Event_EventArgs $args)
    {
        $this->prepareHook('updateOrder', $args->get('entity'));
    }

    private function prepareHook($hook, $data = array())
    {
        if ($this->permitTracking()) {
            $track = Shopware()->Session()->offsetExists('finteza_tracks') ? Shopware()->Session()->offsetGet('finteza_tracks') : '';
            $track .= $this->getTrack($hook, $data);

            Shopware()->Session()->offsetSet('finteza_tracks', $track);
        }
    }

    private function getTrack($hook, $data)
    {
        $encodedData = json_encode($data, JSON_UNESCAPED_SLASHES);

        $js  = 'fz(\'ecommerce\', {';
        $js .= 'actionId: \'' . $hook . '\',';
        $js .= 'shopId: \'shopware\',';
        $js .= 'signature: \'' . $this->getSignature($encodedData) . '\',';
        $js .= 'data: ' . json_encode($data);
        $js .= '});';
        $js .= "\n";

        return $js;
    }

    private function getSignature($data)
    {
        return hash('sha256', $this->Config()->get('FINTEZA_SIGNATURE') . ';' . $this->Config()->get('FINTEZA_WEBSITE_ID') . ';' . $data);
    }

    private function permitInit()
    {
        if ($this->Config()->get('FINTEZA_WEBSITE_ID') != '') {
            return true;
        }
    }

    private function permitTracking()
    {
        if ($this->permitInit() && $this->Config()->get('FINTEZA_SIGNATURE') != '' && $this->Config()->get('FINTEZA_TRACKING_HOOKS') == true) {
            return true;
        }
    }

    private function getSiteUrl()
    {
        $shop = Shopware()->Models()->getRepository('Shopware\Models\Shop\Shop')->getActiveDefault();

        return 'https://' . $shop->getHost() . $shop->getBasePath();
    }

    private function ping($url)
    {
        try {
            $ch = curl_init();

            curl_setopt($ch, CURLOPT_HEADER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'User-Agent: Shopware/' . Shopware()->Config()->version . '; ' . $this->getSiteUrl()
            ));
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_exec($ch);

            curl_close($ch);

            return true;
        } catch (Exception $exception) {
            return false;
        }
    }
}
