<?php
/**
 * Backend controller
 */

use Shopware\Components\CSRFWhitelistAware;
use Shopware\Components\CacheManager;
use Shopware\Models\Order\Order;
use Shopware\Models\Article\Article;

class Shopware_Controllers_Backend_FintezaAnalytics extends Shopware_Controllers_Backend_ExtJs implements CSRFWhitelistAware
{
    private $em;
    private $config;
    private $api_url = 'https://panel.finteza.com/register?utm_source=shopware.admin&utm_medium=link&utm_term=finteza.register&utm_content=finteza.plugin.shopware&utm_campaign=finteza.shopware';
    private $fields = array(
        'FINTEZA_AUTH'           => false,
        'FINTEZA_WEBSITE_ID'     => '',
        'FINTEZA_TRACKING_HASH'  => false,
        'FINTEZA_TRACKING_LINK'  => true,
        'FINTEZA_EXACT_TIME'     => false,
        'FINTEZA_TRACKING_HOOKS' => false,
        'FINTEZA_SIGNATURE'      => '',
    );

    public function __construct(Enlight_Controller_Request_Request $request, Enlight_Controller_Response_Response $response)
    {
        parent::__construct($request, $response);

        $this->em = Shopware()->Models();
        $this->config = Shopware()->Plugins()->Frontend()->FintezaAnalytics()->Config()->toArray();
    }

    public function getWhitelistedCSRFActions()
    {
        return [
            'index',
            'getFields',
            'registerUser',
            'saveConfig',
        ];
    }

    public function indexAction()
    {
        $this->View()->loadTemplate('backend/finteza_analytics/app.js');
    }

    public function getFieldsAction()
    {
        $data = $this->config;

        $data['register_name'] = Shopware()->Container()->get('Auth')->getIdentity()->name;
        $data['register_email'] = Shopware()->Config()->get('mail');

        $this->View()->assign(array(
            'success' => true,
            'data'    => array($data),
        ));
    }

    public function registerUserAction()
    {
        $data = array();
        $curl = array();

        $params = $this->Request()->getParams();

        if ($params['register_agreement'] == 'false') {
            $data['error'] = 'error_register_agreement';
        }

        if ($params['register_privacy'] == 'false') {
            $data['error'] = 'error_register_privacy';
        }

        if (strlen($params['register_password']) < 6) {
            $data['error'] = 'error_register_password';
        }

        if ($params['register_email'] == '') {
            $data['error'] = 'error_register_email';
        }

        if ($params['register_fullname'] == '') {
            $data['error'] = 'error_register_fullname';
        }

        if (isset($data['error'])) {
            $this->View()->assign(array(
                'success' => false,
                'data'    => $data['error'],
            ));

            return;
        }

        $curl_data = array(
            'email'      => $params['register_email'],
            'password'   => $params['register_password'],
            'fullname'   => $params['register_fullname'],
            'company'    => $params['register_company'],
            'website'    => $this->getSiteUrl(),
            'utc_offset' => $this->getTimeOffset(),
        );

        $return = $this->curl($curl_data);

        $result = json_decode($return['result'], true);

        if ($result['status']) {
            if (isset($result['website'])) {
                $this->save('FINTEZA_WEBSITE_ID', $result['website']);
                $this->save('FINTEZA_AUTH', true);

                $data['success'] = 'success_user_create';
            } else {
                $data['error'] = 'error_register_0';
            }
        } else {
            if ($result['error'] == 1) {
                $data['error'] = 'error_register_1';
            } elseif ($result['error'] == 2) {
                $data['error'] = 'error_register_2';
            } elseif ($result['error'] == 3) {
                $data['error'] = 'error_register_3';
            } elseif ($result['error'] == 4) {
                $data['error'] = 'error_register_4';
            } elseif ($result['error'] == 5) {
                $data['error'] = 'error_register_5';
            } elseif ($result['error'] == 6) {
                $data['error'] = 'error_register_6';
            } else {
                $data['error'] = 'error_register_0';
            }
        }

        if (isset($data['error'])) {
            $this->View()->assign(array(
                'success' => false,
                'data'    => $data['error'],
            ));
        } else {
            $this->View()->assign(array(
                'success' => true,
                'data'    => $data['success'],
            ));
        }
    }

    public function saveConfigAction()
    {
        $data = $this->Request()->getParams();
        $params = json_decode($data['params'], true);

        foreach ($params as $param => $value) {
            if (isset($this->fields[$param])) {
                $this->save($param, $value);
            }
        }

        $this->clearCache();

        $this->View()->assign(array(
            'success' => true,
            'data'    => 'success_config_save',
        ));
    }

    private function save($field, $value)
    {
        $writer = $this->get('config_writer');
        $writer->save($field, $value);
    }

    private function clearCache()
    {
        $cacheManager = $this->get('shopware.cache_manager');
        $cacheManager->clearConfigCache();
    }

    private function getTimeOffset()
    {
        return date('Z') / -60;
    }

    private function getSiteUrl()
    {
        $shop = $this->em->getRepository('Shopware\Models\Shop\Shop')->getActiveDefault();

        return 'https://' . $shop->getHost() . $shop->getBasePath();
    }

    private function curl($params = null)
    {
        $url = $this->api_url . '&back_ref=' . urlencode($this->getSiteUrl());
        $data = array();

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_HEADER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: multipart/form-data'));
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_URL, $url);

        if (isset($params)) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
        }

        $data['result'] = curl_exec($ch);
        $data['info'] = curl_getinfo($ch);

        curl_close($ch);

        return $data;
    }
}
