//{namespace name="backend/finteza_analytics/view/main"}

//{block name="backend/finteza_analytics/controller/main"}
Ext.define('Shopware.apps.FintezaAnalytics.controller.Main', {
    extend: 'Ext.app.Controller',
    mainWindow: null,
    init: function () {
        var me = this;

        me.control({
            'register': {
                'register-send': me.registerUser,
                'check-button': me.checkButton,
            },
            'general': {
                'general-send': me.saveConfig,
            },
        });

        var store = me.subApplication.getStore('Settings');

        store.load({
            callback: function (data) {
                me.mainWindow = me.getView('main.Window').create({
                    record: data
                }).show();
            }
        });

        me.callParent(arguments);
    },
    checkButton: function (win) {
        var me = this,
            register_privacy = win.down('checkbox[name=register_privacy]').getValue(),
            register_agreement = win.down('checkbox[name=register_agreement]').getValue();

        if (register_privacy === false || register_agreement === false) {
            win.down('button[name=register_button]').setDisabled(true);
        } else {
            win.down('button[name=register_button]').setDisabled(false);
        }
    },
    registerUser: function (win) {
        var me = this,
            store = me.subApplication.getStore('Settings');

        win.up('window').setLoading(true);

        Ext.Ajax.request({
            url: '{url controller="finteza_analytics" action="registerUser"}',
            method: 'POST',
            params: {
                register_fullname: win.down('textfield[name=register_fullname]').getValue(),
                register_company: win.down('textfield[name=register_company]').getValue(),
                register_email: win.down('textfield[name=register_email]').getValue(),
                register_password: win.down('textfield[name=register_password]').getValue(),
                register_privacy: win.down('checkbox[name=register_privacy]').getValue(),
                register_agreement: win.down('checkbox[name=register_agreement]').getValue(),
            },
            success: function (response) {
                var response = Ext.JSON.decode(response.responseText);

                me.log(response.data);

                win.up('window').setLoading(false);

                if (response.success) {
                    win.up('window').destroy();

                    store.load({
                        callback: function (data) {
                            me.mainWindow = me.getView('main.Window').create({
                                record: data
                            }).show();
                        }
                    });
                }
            },
        });
    },
    saveConfig: function (win) {
        var me = this,
            body = win.up('window'),
            panel = body.down('form'),
            form = panel.getForm(),
            fields = form.getValues(),
            params = Ext.JSON.encode(fields),
            store = me.subApplication.getStore('Settings');

        win.up('window').setLoading(true);

        Ext.Ajax.request({
            url: '{url controller="finteza_analytics" action="saveConfig"}',
            method: 'POST',
            params: {
                params
            },
            success: function (response) {
                var response = Ext.JSON.decode(response.responseText);

                me.log(response.data);

                win.up('window').destroy();

                store.load({
                    callback: function (data) {
                        me.mainWindow = me.getView('main.Window').create({
                            record: data
                        }).show();
                    }
                });
            },
        });
    },
    log: function (text, total, count) {
        var me = this;

        Shopware.Notification.createGrowlMessage(
            'FintezaAnalytics',
            me.getMessage(text, total, count),
            'FintezaAnalytics',
        );
    },
    getMessage: function (text, total, count) {
        var translations = [];
            translations['error_register_fullname'] = '{s name="error_register_fullname"}Incorrect value for Full Name field{/s}';
            translations['error_register_email'] = '{s name="error_register_email"}Incorrect value for Email field{/s}';
            translations['error_register_password'] = '{s name="error_register_password"}Incorrect value for Password field{/s}';
            translations['error_register_privacy'] = '{s name="error_register_privacy"}Incorrect value for Privacy and data protection policy field{/s}';
            translations['error_register_agreement'] = '{s name="error_register_agreement"}Incorrect value for Subscription service agreement field{/s}';
            translations['error_register_0'] = '{s name="error_register_0"}Registration error{/s}';
            translations['error_register_1'] = '{s name="error_register_1"}An account with this email address already exists{/s}';
            translations['error_register_2'] = '{s name="error_register_2"}Password insufficient length{/s}';
            translations['error_register_3'] = '{s name="error_register_3"}Invalid email address{/s}';
            translations['error_register_4'] = '{s name="error_register_4"}A company with this name already exists{/s}';
            translations['error_register_5'] = '{s name="error_register_5"}Invalid website address{/s}';
            translations['error_register_6'] = '{s name="error_register_6"}Registration limit exceeded{/s}';
            translations['success_user_register'] = '{s name="success_user_register"}Account successfully registered. Please activate your account using the link sent to your registration complete email{/s}';
            translations['success_config_save'] = '{s name="success_config_save"}Configuration saved{/s}';

        return translations[text];
    },
});
//{/block}
