//{namespace name="backend/finteza_analytics/main"}

//{block name="backend/finteza_analytics/view/settings/register"}
Ext.define('Shopware.apps.FintezaAnalytics.view.settings.Register', {
    extend: 'Ext.form.FieldSet',
    alias: 'widget.register',
    stateId: 'register',
    collapsible: true,
    collapsed: false,
    hidden: false,
    width: '100%',
    margin: 5,
    padding: 10,
    border: true,
    defaults: {
        labelWidth: 150,
        anchor: '100%'
    },
    initComponent: function () {
        var me = this;

        me.addEvents(
            'check-button',
            'register-send',
        );

        me.title = '{s name="register_title"}Registration{/s}';
        me.items = me.createForm();

        me.callParent(arguments);
    },
    createForm: function () {
        var me = this,
            data = me.record[0].data;

        return [
            Ext.create('Ext.form.field.Text', {
                name: 'register_fullname',
                fieldLabel: '* {s name="register_fullname"}Your full name{/s}',
                blankText: '{s name="required_field"}This field is required{/s}',
                labelWidth: me.defaults.labelWidth,
                allowBlank: false,
                required: true,
                value: data.register_name,
                inputAttrTpl: 'spellcheck=false',
            }),
            Ext.create('Ext.form.field.Text', {
                name: 'register_company',
                fieldLabel: '{s name="register_company"}Company{/s}',
                labelWidth: me.defaults.labelWidth,
                inputAttrTpl: 'spellcheck=false',
            }),
            Ext.create('Ext.form.field.Text', {
                name: 'register_email',
                fieldLabel: '* {s name="register_email"}Email{/s}',
                blankText: '{s name="required_field"}This field is required{/s}',
                labelWidth: me.defaults.labelWidth,
                allowBlank: false,
                required: true,
                vtype: 'email',
                value: data.register_email,
                inputAttrTpl: 'spellcheck=false',
            }),
            Ext.create('Ext.container.Container', {
                html: '{s name="register_email_help"}Will be used as login{/s}',
                style: 'font-style: italic; color: #999999; margin-left: 155px; padding: 0 0 10px;',
            }),
            Ext.create('Ext.form.field.Text', {
                name: 'register_password',
                fieldLabel: '* {s name="register_password"}Password{/s}',
                blankText: '{s name="required_field"}This field is required{/s}',
                labelWidth: me.defaults.labelWidth,
                allowBlank: false,
                required: true,
                inputType: 'password',
                minLength: 6,
                inputAttrTpl: 'spellcheck=false',
            }),
            Ext.create('Ext.container.Container', {
                html: '{s name="register_password_help"}Must have at least 6 characters, upper and lower case letters and numbers{/s}',
                style: 'font-style: italic; color: #999999; margin-left: 155px; padding: 0 0 10px;',
            }),
            Ext.create('Ext.form.field.Checkbox', {
                name: 'register_privacy',
                boxLabel: '{s name="register_privacy"}I have read and understood <a href="https://www.finteza.com/privacy?utm_source=shopware.admin&utm_medium=link&utm_term=finteza.privacy.policy&utm_content=finteza.plugin.shopware&utm_campaign=finteza.shopware" target="_blank">privacy and data protection policy</a>{/s}',
                blankText: '{s name="required_field"}This field is required{/s}',
                labelWidth: me.defaults.labelWidth,
                allowBlank: false,
                required: true,
                inputValue: true,
                uncheckedValue: false,
                checked: true,
                fieldStyle: 'margin-left: 155px; font-weight: bold;',
                handler: function () {
                    me.fireEvent('check-button', me);
                }
            }),
            Ext.create('Ext.form.field.Checkbox', {
                name: 'register_agreement',
                boxLabel: '{s name="register_agreement"}I agree to <a href="https://www.finteza.com/agreement?utm_source=shopware.admin&utm_medium=link&utm_term=finteza.subscription.agreement&utm_content=finteza.plugin.shopware&utm_campaign=finteza.shopware" target="_blank">subscription service agreement</a>{/s}',
                blankText: '{s name="required_field"}This field is required{/s}',
                labelWidth: me.defaults.labelWidth,
                allowBlank: false,
                required: true,
                inputValue: true,
                uncheckedValue: false,
                checked: true,
                fieldStyle: 'margin-left: 155px; font-weight: bold;',
                handler: function () {
                    me.fireEvent('check-button', me);
                }
            }),
            Ext.create('Ext.button.Button', {
                name: 'register_button',
                cls: 'primary small',
                text: '{s name="register_button"}Register{/s}',
                handler: function () {
                    me.fireEvent('register-send', me);
                }
            })
        ];
    }
});
//{/block}
